@@ -329,7 +329,7 @@ void wf::pointer_t::grab_surface(wf::surface_interface_t *surface)
 }
 
 /* ----------------------- Input event processing --------------------------- */
-void wf::pointer_t::handle_pointer_button(wlr_event_pointer_button *ev,
+void wf::pointer_t::handle_pointer_button(wlr_pointer_button_event *ev,
     input_event_processing_mode_t mode)
 {
     seat->break_mod_bindings();
@@ -379,7 +379,7 @@ void wf::pointer_t::check_implicit_grab()
     }
 }
 
-void wf::pointer_t::send_button(wlr_event_pointer_button *ev, bool has_binding)
+void wf::pointer_t::send_button(wlr_pointer_button_event *ev, bool has_binding)
 {
     if (input->active_grab)
     {
@@ -446,7 +446,7 @@ void wf::pointer_t::send_motion(uint32_t time_msec, wf::pointf_t local)
     }
 }
 
-void wf::pointer_t::handle_pointer_motion(wlr_event_pointer_motion *ev,
+void wf::pointer_t::handle_pointer_motion(wlr_pointer_motion_event *ev,
     input_event_processing_mode_t mode)
 {
     if (input->input_grabbed() &&
@@ -483,16 +483,16 @@ void wf::pointer_t::handle_pointer_motion(wlr_event_pointer_motion *ev,
     }
 
     /* XXX: maybe warp directly? */
-    wlr_cursor_move(seat->cursor->cursor, ev->device, dx, dy);
+    wlr_cursor_move(seat->cursor->cursor, &ev->pointer->base, dx, dy);
     update_cursor_position(ev->time_msec);
 }
 
 void wf::pointer_t::handle_pointer_motion_absolute(
-    wlr_event_pointer_motion_absolute *ev, input_event_processing_mode_t mode)
+    wlr_pointer_motion_absolute_event *ev, input_event_processing_mode_t mode)
 {
     // next coordinates
     double cx, cy;
-    wlr_cursor_absolute_to_layout_coords(seat->cursor->cursor, ev->device,
+    wlr_cursor_absolute_to_layout_coords(seat->cursor->cursor, &ev->pointer->base,
         ev->x, ev->y, &cx, &cy);
 
     // send relative motion
@@ -517,7 +517,7 @@ void wf::pointer_t::handle_pointer_motion_absolute(
     update_cursor_position(ev->time_msec);
 }
 
-void wf::pointer_t::handle_pointer_axis(wlr_event_pointer_axis *ev,
+void wf::pointer_t::handle_pointer_axis(wlr_pointer_axis_event *ev,
     input_event_processing_mode_t mode)
 {
     bool handled_in_binding = input->get_active_bindings().handle_axis(
@@ -550,7 +550,7 @@ void wf::pointer_t::handle_pointer_axis(wlr_event_pointer_axis *ev,
         mult * ev->delta, mult * ev->delta_discrete, ev->source);
 }
 
-void wf::pointer_t::handle_pointer_swipe_begin(wlr_event_pointer_swipe_begin *ev,
+void wf::pointer_t::handle_pointer_swipe_begin(wlr_pointer_swipe_begin_event *ev,
     input_event_processing_mode_t mode)
 {
     wlr_pointer_gestures_v1_send_swipe_begin(
@@ -559,14 +559,14 @@ void wf::pointer_t::handle_pointer_swipe_begin(wlr_event_pointer_swipe_begin *ev
 }
 
 void wf::pointer_t::handle_pointer_swipe_update(
-    wlr_event_pointer_swipe_update *ev, input_event_processing_mode_t mode)
+    wlr_pointer_swipe_update_event *ev, input_event_processing_mode_t mode)
 {
     wlr_pointer_gestures_v1_send_swipe_update(
         wf::get_core().protocols.pointer_gestures, seat->seat,
         ev->time_msec, ev->dx, ev->dy);
 }
 
-void wf::pointer_t::handle_pointer_swipe_end(wlr_event_pointer_swipe_end *ev,
+void wf::pointer_t::handle_pointer_swipe_end(wlr_pointer_swipe_end_event *ev,
     input_event_processing_mode_t mode)
 {
     wlr_pointer_gestures_v1_send_swipe_end(
@@ -574,7 +574,7 @@ void wf::pointer_t::handle_pointer_swipe_end(wlr_event_pointer_swipe_end *ev,
         ev->time_msec, ev->cancelled);
 }
 
-void wf::pointer_t::handle_pointer_pinch_begin(wlr_event_pointer_pinch_begin *ev,
+void wf::pointer_t::handle_pointer_pinch_begin(wlr_pointer_pinch_begin_event *ev,
     input_event_processing_mode_t mode)
 {
     wlr_pointer_gestures_v1_send_pinch_begin(
@@ -583,14 +583,14 @@ void wf::pointer_t::handle_pointer_pinch_begin(wlr_event_pointer_pinch_begin *ev
 }
 
 void wf::pointer_t::handle_pointer_pinch_update(
-    wlr_event_pointer_pinch_update *ev, input_event_processing_mode_t mode)
+    wlr_pointer_pinch_update_event *ev, input_event_processing_mode_t mode)
 {
     wlr_pointer_gestures_v1_send_pinch_update(
         wf::get_core().protocols.pointer_gestures, seat->seat,
         ev->time_msec, ev->dx, ev->dy, ev->scale, ev->rotation);
 }
 
-void wf::pointer_t::handle_pointer_pinch_end(wlr_event_pointer_pinch_end *ev,
+void wf::pointer_t::handle_pointer_pinch_end(wlr_pointer_pinch_end_event *ev,
     input_event_processing_mode_t mode)
 {
     wlr_pointer_gestures_v1_send_pinch_end(
