@@ -8,7 +8,7 @@ namespace wf
 struct switch_device_t : public input_device_impl_t
 {
     wf::wl_listener_wrapper on_switch;
-    void handle_switched(wlr_event_switch_toggle *ev);
+    void handle_switched(wlr_switch_toggle_event *ev);
 
     switch_device_t(wlr_input_device *dev);
     virtual ~switch_device_t() = default;
