@@ -21,11 +21,11 @@ wf::touch_interface_t::touch_interface_t(wlr_cursor *cursor, wlr_seat *seat,
     // connect handlers
     on_down.set_callback([=] (void *data)
     {
-        auto ev   = static_cast<wlr_event_touch_down*>(data);
+        auto ev   = static_cast<wlr_touch_down_event*>(data);
         auto mode = emit_device_event_signal("touch_down", ev);
 
         double lx, ly;
-        wlr_cursor_absolute_to_layout_coords(cursor, ev->device,
+        wlr_cursor_absolute_to_layout_coords(cursor, &ev->touch->base,
             ev->x, ev->y, &lx, &ly);
 
         wf::pointf_t point;
@@ -38,7 +38,7 @@ wf::touch_interface_t::touch_interface_t(wlr_cursor *cursor, wlr_seat *seat,
 
     on_up.set_callback([=] (void *data)
     {
-        auto ev   = static_cast<wlr_event_touch_up*>(data);
+        auto ev   = static_cast<wlr_touch_up_event*>(data);
         auto mode = emit_device_event_signal("touch_up", ev);
         handle_touch_up(ev->touch_id, ev->time_msec, mode);
         wlr_idle_notify_activity(wf::get_core().protocols.idle,
@@ -48,12 +48,12 @@ wf::touch_interface_t::touch_interface_t(wlr_cursor *cursor, wlr_seat *seat,
 
     on_motion.set_callback([=] (void *data)
     {
-        auto ev   = static_cast<wlr_event_touch_motion*>(data);
+        auto ev   = static_cast<wlr_touch_motion_event*>(data);
         auto mode = emit_device_event_signal("touch_motion", ev);
 
         double lx, ly;
         wlr_cursor_absolute_to_layout_coords(
-            wf::get_core_impl().seat->cursor->cursor, ev->device,
+            wf::get_core_impl().seat->cursor->cursor, &ev->touch->base,
             ev->x, ev->y, &lx, &ly);
 
         wf::pointf_t point;
