@@ -599,7 +599,7 @@ class wayfire_xwayland_view : public wayfire_xwayland_view_base
         {
             wf::view_hints_changed_signal data;
             data.view = this;
-            if (xw->hints_urgency)
+            if (xw->hints->flags & XCB_ICCCM_WM_HINT_X_URGENCY)
             {
                 data.demands_attention = true;
             }
